Contribute to Merlin
====================
.. admonition:: Estimated time

      * 10 minutes

.. admonition:: You will learn

      * How to post issues to the merlin repo.
      * Guidelines for contributing to merlin.

.. contents:: Table of Contents:
  :local:

Issues
++++++
Found a bug? Have an idea? Or just want to ask a question?
`Create a new issue <https://github.com/LLNL/merlin/issues/new/choose>`_ on GitHub.

Bug Reports 🐛
--------------
To report a bug, simply navigate to `Issues <https://github.com/LLNL/merlin/issues>`_, click "New Issue", then click "Bug report". Then simply fill out a few fields such as "Describe the bug" and "Expected behavior". Try to fill out every field as it will help us figure out your bug sooner.

Feature Requests 🚀
-------------------
We are still adding new features to merlin. To suggest one, simply navigate to `Issues <https://github.com/LLNL/merlin/issues>`_, click "New Issue", then click "Feature request". Then fill out a few fields such as "What problem is this feature looking to solve?"

Questions 🤓
------------
.. note::

    Who knows? Your question may already be answered in the :doc:`FAQ<../faq>`.

We encourage questions to be asked in a collaborative setting: on GitHub, direct any questions to `General Questions <https://github.com/LLNL/merlin/issues/new?labels=question&template=question.md&title=%5BQ%2FA%5D+>`_ in Issues.

Any questions can also be sent to merlin@llnl.gov.

Contributing
++++++++++++
Merlin is an open source project, so contributions are welcome. Contributions can be anything from bugfixes, documentation, or even new core features.

Contributing to Merlin is easy! Just `send us a pull request <https://github.com/LLNL/merlin/pulls>`_ from your fork. Before you send it, summarize your change in the ``[Unreleased]`` section of ``CHANGELOG.md`` and make sure develop is the destination branch. We also appreciate `squash commits <https://github.com/LLNL/merlin/wiki/Squash-commits>`_ before pull requests are merged.

Merlin uses a rough approximation of the Git Flow branching model. The develop branch contains the latest contributions, and master is always tagged and points to the latest stable release.

If you're a contributor, try to test and run on develop. That's where all the magic is happening (and where we hope bugs stop).
